# -*- coding: utf-8 -*-

# Copyright (C) 2012-2013 Avencall
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>


class WebServiceError(Exception):
    pass


class WebServiceRequestError(WebServiceError):

    def __init__(self, code, msg, url=''):
        self.code = code
        self.msg = msg
        self.url = url

    def __str__(self):
        return 'HTTP Error %s: %s %s' % (self.code, self.msg, self.url)
